<?php
include("mysql2json.class.php");

//DBモデル
class ModelDatabase {
	protected $tblname;
	protected $columns;
	public $posts;
	public $gets;
	public $sql = "";
	public $data_type = "";	//"" or json
	public $error_code = "";
	public $error_message = "";

	//カラム取得
	public function getParams() {
		$ary = Array();
		foreach ($this->columns as $key => $val) {
			if (isset($key,$this->posts[$key])) {
				$ary[$key] = $this->posts[$key];
			} else {
				$ary[$key] = "";
			}
		}
		if ($ary["time_stamp"] == "") {
			$ary["time_stamp"] = date("Y-m-d H:i:s");
		}
		return($ary);
	}

	//キー取得
	public function getIndexes() {
		$ary = Array();
		foreach ($this->columns as $key => $val) {
			if ($val == "index") {
				if (isset($key,$this->posts[$key])) {
					$ary[$key] = $this->posts[$key];
				} elseif (isset($key,$this->gets[$key])) {
					$ary[$key] = $this->gets[$key];
				} else {
					$ary[$key] = "";
				}
			}
		}
		return($ary);
	}

	//where句
	public function getConds($keys,$alias = "") {
		$conds = array();
		$conds[] = "0=0";
		foreach ($keys as $key => $val) {
			if ($val != "") {
				$cond = "";
				if ($alias != "") {
					$cond .= $alias.".";
				}
				$cond .= $key;
				if (strpos($val, ",") !== false) {
					$cond .= " in('".str_replace(",","','",addslashes($val))."')";
				} else if (strpos($val, "%") !== false) {
					$cond .= " like'".addslashes($val)."'";
				} else {
					$cond .= "='".addslashes($val)."'";
				}
				$conds[] = $cond;
			}
		}
		return(implode(' AND ', $conds));
	}

	//where句
	public function getOrders($keys,$alias = "") {
		$orderby = array();
		foreach ($keys as $key => $val) {
			if ($val == "desc") {
				if ($alias == "") {
					$orderby[] = $key." ".$val;
				} else {
					$orderby[] = $alias.".".$key." ".$val;
				}
			} else {
				if ($alias == "") {
					$orderby[] = $key;
				} else {
					$orderby[] = $alias.".".$key;
				}
			}
		}
		return(implode(',', $orderby));
	}

	//query
	public function query($sql) {
		global $conn;
		$this->sql = $sql;
		if (!($rs = mysqli_query($conn,$sql))) {
			$this->db_error(__FUNCTION__,$sql);
		}
		if ($this->data_type == "json") {
			if ($rs == "") {
				$json = $this->return_json();
				return($json);
			}
			//レコードをJSONに変換
			$num = mysqli_affected_rows($conn);
			$objJSON = new mysql2json();
			$json = trim($objJSON->getJSON($rs,$num));
			$json = substr($json, 0, -1);		//json調整
			return($json);
		}
		return($rs);
	}

	//execute
	public function execute($sql) {
		global $conn;
		$this->sql = $sql;
		if (!($rtn = mysqli_query($conn,$sql))) {
			$rtn = $this->db_error(__FUNCTION__,$sql);
		}
		if ($this->data_type == "json") {
			$rtn = $this->return_json();
		}
		return($rtn);
	}

	// select
	public function select($keys,$orders = null,$row = 0) {
		$conds = $this->getConds($keys);
		if ($orders == null) {
			$orderby = $this->getOrders($keys);
		} else {
			$orderby = $this->getOrders($orders);
		}
		if ($row > 0) {
			$limit = "limit 0,".$row;
		}
		$sql = sprintf(
			"SELECT * FROM %s WHERE %s order by %s %s",
			$this->tblname,
			$conds,
			$orderby,
			$limit
		);
		$rs = $this->query($sql);
		return($rs);
	}

	// max
	public function max($keys,$col) {
		global $conn;
		$conds = $this->getConds($keys);
		$sql = sprintf(
			"SELECT max(%s) as %s FROM %s WHERE %s",
			$col,
			$col,
			$this->tblname,
			$conds
		);
		$this->sql = $sql;
		if (!($rs = mysqli_query($conn,$sql))) {
			$this->db_error(__FUNCTION__,$sql);
		}
		while ($item = mysqli_fetch_array($rs)) {
			return($item[$col]);
		}
	}

	// count
	public function count($keys) {
		global $conn;
		$conds = $this->getConds($keys);
		$sql = sprintf(
			"SELECT count(*) as cnt FROM %s WHERE %s",
			$this->tblname,
			$conds
		);
		if (!($rs = mysqli_query($conn,$sql))) {
			$this->db_error(__FUNCTION__,$sql);
		}
		while ($item = mysqli_fetch_array($rs)) {
			return($item["cnt"]);
		}
		return(0);
	}

	// insert
	public function insert($params) {
		$values = array();
		foreach ($params as $key => $val) {
			$values[] = "'".addslashes($val)."'";
		}
		$sql = sprintf(
			"INSERT INTO %s VALUES (%s)",
			$this->tblname,
			implode(',', $values)
		);
		$rs = $this->execute($sql);
		return($rs);
	}

	// update
	public function update($params,$keys) {
		$fields = array();
		foreach ($params as $key => $val) {
			if ($val != "") {
				$fields[] = $key."='".addslashes($val)."'";
			}
		}
		$conds = $this->getConds($keys);
		if (trim($conds) == "0=0") {
			return;
		}
		$sql = sprintf(
			"UPDATE %s SET %s WHERE %s",
			$this->tblname,
			implode(',', $fields),
			$conds
		);
		$rs = $this->execute($sql);
		return($rs);
	}

	// delete
	public function delete($keys) {
		$conds = $this->getConds($keys);
		if (trim($conds) == "0=0") {
			return;
		}
		$sql = sprintf(
			"DELETE FROM %s WHERE %s",
			$this->tblname,
			$conds
		);
		$rs = $this->execute($sql);
		return($rs);
	}

	// メイン処理(insert)
	function insertControl() {
		$params = $this->getParams();
		$rtn = $this->insert($params);
		return($rtn);
	}
	
	// メイン処理(update)
	function updateControl() {
		$params = $this->getParams();
		$keys = $this->getIndexes();
		$rtn = $this->update($params,$keys);
		return($rtn);
	}
	
	// メイン処理(delete)
	function deleteControl() {
		$keys = $this->getIndexes();
		$rtn = $this->delete($keys);
		return($rtn);
	}

	// メイン処理(select)
	function selectControl() {
		$keys = $this->getIndexes();
		$rtn = $this->select($keys);
		return($rtn);
	}
	// メイン処理(select)
	function selectControl2($orders,$row) {
		$keys = $this->getIndexes();
		$rtn = $this->select($keys,$orders,$row);
		return($rtn);
	}
	
	// メイン処理(count)
	function countControl() {
		$keys = $this->getIndexes();
		$rtn = $this->count($keys);
		if ($this->data_type == "json") {
			$data = array('cnt'=>$rtn);
			$rtn = json_encode($data);
		}
		return($rtn);
	}
	
	// メイン処理(Common)
	function commonControl($func) {
		return($rtn);
	}

	// DBエラー処理
	public function db_error($func_name,$sql) {
		$message = $func_name."() error occured.¥n";
		$message .= $sql."¥n";
		$this->error_code = 9;
		$this->error_message = $message;
		//print $message;
		return($message);
	}
	
	// DBエラー処理
	public function return_json() {
		$data[] = array(
			'error_code'=>$this->error_code,
			'error_message'=>$this->error_message
			//'sql'=>$this->sql
		);
		return(json_encode($data));
	}
}

?>