<?php

/**
 * Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * ProductAdvertisingAPI
 *
 * https://webservices.amazon.com/paapi5/documentation/index.html
 */

/*
 * This sample code snippet is for ProductAdvertisingAPI 5.0's SearchItems API
 *
 * For more details, refer: https://webservices.amazon.com/paapi5/documentation/search-items.html
 */

use Amazon\ProductAdvertisingAPI\v1\ApiException;
use Amazon\ProductAdvertisingAPI\v1\com\amazon\paapi5\v1\api\DefaultApi;
use Amazon\ProductAdvertisingAPI\v1\com\amazon\paapi5\v1\PartnerType;
use Amazon\ProductAdvertisingAPI\v1\com\amazon\paapi5\v1\ProductAdvertisingAPIClientException;
use Amazon\ProductAdvertisingAPI\v1\com\amazon\paapi5\v1\SearchItemsRequest;
use Amazon\ProductAdvertisingAPI\v1\com\amazon\paapi5\v1\SearchItemsResource;
use Amazon\ProductAdvertisingAPI\v1\Configuration;

require_once(__DIR__ . '/vendor/autoload.php'); // change path as needed

function searchItems($access_key,$secret_key,$associate_id,$keyword)
{
    $config = new Configuration();

    /*
     * Add your credentials
     */
    # Please add your access key here
#    $config->setAccessKey('AKIAJRD53M5QCFMMTMVQ');
    # Please add your secret key here
#    $config->setSecretKey('Mh9l+BCeCBfekwhKtRPXtxQRShvsYwns7YFW2e3B');

    # Please add your access key here
    $config->setAccessKey('AKIAIUIJNJ4DNFNJMGUA');
    # Please add your secret key here
    $config->setSecretKey('l3o6dy1+Himwv28fSdmpHl9HE8L6EOJ3ODgJnYis');

    # Please add your partner tag (store/tracking id) here
    $partnerTag = 'infoking0b5-22';

    /*
     * PAAPI host and region to which you want to send request
     * For more details refer:
     * https://webservices.amazon.com/paapi5/documentation/common-request-parameters.html#host-and-region
     */
//    $config->setHost('webservices.amazon.com');
//    $config->setRegion('us-east-1');
    $config->setHost('webservices.amazon.co.jp');
    $config->setRegion('us-west-2');

    $apiInstance = new DefaultApi(
        /*
         * If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
         * This is optional, `GuzzleHttp\Client` will be used as default.
         */
        new GuzzleHttp\Client(),
        $config
    );

    # Request initialization

    # Specify keywords
//    $keyword = 'Harry Potter';
    //$keyword = 'サッカー';

    /*
     * Specify the category in which search request is to be made
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/use-cases/organization-of-items-on-amazon/search-index.html
     */
    $searchIndex = "All";

    # Specify item count to be returned in search result
    $itemCount = 10;

    /*
     * Choose resources you want from SearchItemsResource enum
     * For more details,
     * refer: https://webservices.amazon.com/paapi5/documentation/search-items.html#resources-parameter
     */
    $resources = [
        SearchItemsResource::ITEM_INFOTITLE,
        SearchItemsResource::ITEM_INFOBY_LINE_INFO,
        SearchItemsResource::ITEM_INFOCONTENT_INFO,
        SearchItemsResource::ITEM_INFOCONTENT_RATING,
        SearchItemsResource::ITEM_INFOCLASSIFICATIONS,
        SearchItemsResource::ITEM_INFOFEATURES,
//        SearchItemsResource::ITEM_INFOMANUFACTURE_INFO,
//        SearchItemsResource::ITEM_INFOPRODUCT_INFO,
//        SearchItemsResource::ITEM_INFOTECHNICAL_INFO,
        SearchItemsResource::OFFERSLISTINGSPRICE,
        SearchItemsResource::IMAGESVARIANTSMEDIUM,
        SearchItemsResource::IMAGESVARIANTSLARGE
    ];

    # Forming the request
    $searchItemsRequest = new SearchItemsRequest();
    $searchItemsRequest->setSearchIndex($searchIndex);
    $searchItemsRequest->setKeywords($keyword);
    $searchItemsRequest->setItemCount($itemCount);
    $searchItemsRequest->setPartnerTag($partnerTag);
    $searchItemsRequest->setPartnerType(PartnerType::ASSOCIATES);
    $searchItemsRequest->setResources($resources);

    # Validating request
    $invalidPropertyList = $searchItemsRequest->listInvalidProperties();
    $length = count($invalidPropertyList);
    if ($length > 0) {
        echo "Error forming the request", PHP_EOL;
        foreach ($invalidPropertyList as $invalidProperty) {
            echo $invalidProperty, PHP_EOL;
        }
        return;
    }

    # Sending the request
    try {
        $data = array();
        $searchItemsResponse = $apiInstance->searchItems($searchItemsRequest);

        echo 'API called successfully', PHP_EOL;
        echo 'Complete Response: ', $searchItemsResponse, PHP_EOL;

        # Parsing the response
        if ($searchItemsResponse->getSearchResult() !== null) {
            echo '<br><br>Printing first item information in SearchResult:', PHP_EOL;
            foreach ( $searchItemsResponse->getSearchResult()->getItems() as $item ) {
                $rec = [];
                //$item = $searchItemsResponse->getSearchResult()->getItems()[9];
                if ($item !== null) {
                    print "<br>";
                    print_r($item->getItemInfo()->getContentInfo());
                    print "<br>";

                    if ($item->getASIN() !== null) {
                        //echo "<br>ASIN: ", $item->getASIN(), PHP_EOL;
                        $rec["ASIN"] = $item->getASIN();
                    }
                    if ($item->getDetailPageURL() !== null) {
                        //echo "<br>DetailPageURL: ", $item->getDetailPageURL(), PHP_EOL;
                        $rec["URL"] = $item->getDetailPageURL();
                    }
                    if ($item->getItemInfo() !== null
                        and $item->getItemInfo()->getContentInfo() !== null
                        and $item->getItemInfo()->getContentInfo()->getPublicationDate() !== null) {
                        //echo "<br>PublicationDate: ", $item->getItemInfo()->getContentInfo()->getPublicationDate()->getDisplayValue(), PHP_EOL;
                        $rec["PublicationDate"] = $item->getItemInfo()->getContentInfo()->getPublicationDate()->getDisplayValue();
                    }
                    if ($item->getItemInfo() !== null
                        and $item->getItemInfo()->getByLineInfo() !== null
                        and $item->getItemInfo()->getByLineInfo()->getBrand() !== null) {
                        //echo "<br>Brand: ", $item->getItemInfo()->getByLineInfo()->getBrand()->getDisplayValue(), PHP_EOL;
                        $rec["Brand"] = $item->getItemInfo()->getByLineInfo()->getBrand()->getDisplayValue();
                    }
                    if ($item->getItemInfo() !== null
                        and $item->getItemInfo()->getByLineInfo() !== null
                        and $item->getItemInfo()->getByLineInfo()->getManufacturer() !== null) {
                        //echo "<br>Manufacturer: ", $item->getItemInfo()->getByLineInfo()->getManufacturer()->getDisplayValue(), PHP_EOL;
                        $rec["Manufacturer"] = $item->getItemInfo()->getByLineInfo()->getManufacturer()->getDisplayValue();
                    }
                    if ($item->getItemInfo() !== null
                        and $item->getItemInfo()->getClassifications() !== null
                        and $item->getItemInfo()->getClassifications()->getBinding() !== null) {
                        //echo "<br>Class: ", $item->getItemInfo()->getClassifications()->getBinding()->getDisplayValue(), PHP_EOL;
                        $rec["Class"] = $item->getItemInfo()->getClassifications()->getBinding()->getDisplayValue();
                    }
                    if ($item->getItemInfo() !== null
                        and $item->getItemInfo()->getFeatures() !== null
                        and $item->getItemInfo()->getFeatures()->getDisplayValues() !== null) {
                        //echo "<br>Features: ", $item->getItemInfo()->getFeatures()->getDisplayValues()[0], PHP_EOL;
                        $rec["Features"] = $item->getItemInfo()->getFeatures()->getDisplayValues()[0];
                    }
                    if ($item->getImages() !== null
                        and $item->getImages()->getPrimary() !== null
                        and $item->getImages()->getPrimary()->getMedium() !== null) {
                        //echo "<br>Medium Img: ", $item->getImages()->getPrimary()->getMedium()->getURL(), PHP_EOL;
                        $rec["Medium Img"] = $item->getImages()->getPrimary()->getMedium()->getURL();
                    }
                    if ($item->getImages() !== null
                        and $item->getImages()->getPrimary() !== null
                        and $item->getImages()->getPrimary()->getLarge() !== null) {
                        //echo "<br>Large Img: ", $item->getImages()->getPrimary()->getLarge()->getURL(), PHP_EOL;
                        $rec["Large Img"] = $item->getImages()->getPrimary()->getLarge()->getURL();
                    }
                    if ($item->getImages() !== null
                        and $item->getImages()->getVariants() !== null
                        and $item->getImages()->getVariants()[0]->getMedium() !== null) {
                        //echo "<br>Medium Img: ", $item->getImages()->getVariants()[0]->getMedium()->getURL(), PHP_EOL;
                        $rec["Medium Img"] = $item->getImages()->getVariants()[0]->getMedium()->getURL();
                    }
                    if ($item->getImages() !== null
                        and $item->getImages()->getVariants() !== null
                        and $item->getImages()->getVariants()[0]->getLarge() !== null) {
                        //echo "<br>Large Img: ", $item->getImages()->getVariants()[0]->getLarge()->getURL(), PHP_EOL;
                        $rec["Large Img"] = $item->getImages()->getVariants()[0]->getLarge()->getURL();
                    }
                    if ($item->getItemInfo() !== null
                        and $item->getItemInfo()->getTitle() !== null
                        and $item->getItemInfo()->getTitle()->getDisplayValue() !== null) {
                        //echo "<br>Title: ", $item->getItemInfo()->getTitle()->getDisplayValue(), PHP_EOL;
                        $rec["Title"] = $item->getItemInfo()->getTitle()->getDisplayValue();
                    }
                    if ($item->getOffers() !== null
                        and $item->getOffers() !== null
                        and $item->getOffers()->getListings() !== null
                        and $item->getOffers()->getListings()[0]->getPrice() !== null
                        and $item->getOffers()->getListings()[0]->getPrice()->getDisplayAmount() !== null) {
                        //echo "<br>Buying price: ", $item->getOffers()->getListings()[0]->getPrice()->getDisplayAmount(), PHP_EOL;
                        $rec["Buying price"] = $item->getOffers()->getListings()[0]->getPrice()->getDisplayAmount();
                    }
                    $bi = $item->getItemInfo()->getByLineInfo();
                    if ($bi !== null && $bi->getContributors() !== null) {
                        $bi = $bi->getContributors();
                        $txt = "";
                        foreach ( $bi as $row ) {
                            //echo "<br>".$row->getRole().": ".$row->getName();
                            if ($txt != "") {
                                $txt .= ",";
                            }
                            $txt .= $row->getRole().": ".$row->getName();
                        }
                        if ($txt != "") {
                            $rec["Contributors"] = $txt;
                        }
                    }
                    $data[] = $rec;
                }
            }
        }
        if ($searchItemsResponse->getErrors() !== null) {
            echo PHP_EOL, 'Printing Errors:', PHP_EOL, 'Printing first error object from list of errors', PHP_EOL;
            echo 'Error code: ', $searchItemsResponse->getErrors()[0]->getCode(), PHP_EOL;
            echo 'Error message: ', $searchItemsResponse->getErrors()[0]->getMessage(), PHP_EOL;
        }
    } catch (ApiException $exception) {
        echo "Error calling PA-API 5.0!", PHP_EOL;
        echo "HTTP Status Code: ", $exception->getCode(), PHP_EOL;
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
        if ($exception->getResponseObject() instanceof ProductAdvertisingAPIClientException) {
            $errors = $exception->getResponseObject()->getErrors();
            foreach ($errors as $error) {
                echo "Error Type: ", $error->getCode(), PHP_EOL;
                echo "Error Message: ", $error->getMessage(), PHP_EOL;
            }
        } else {
            echo "Error response body: ", $exception->getResponseBody(), PHP_EOL;
        }
    } catch (Exception $exception) {
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
    }
    print "<br>===============================<br>";
    print_r($data);
    return($data);
}

function searchItemsWithHttpInfo()
{
    $config = new Configuration();

    /*
     * Add your credentials
     */
    # Please add your access key here
    $config->setAccessKey('<YOUR ACCESS KEY>');
    # Please add your secret key here
    $config->setSecretKey('<YOUR SECRET KEY>');

    # Please add your partner tag (store/tracking id) here
    $partnerTag = '<YOUR PARTNER TAG>';

    /*
     * PAAPI host and region to which you want to send request
     * For more details refer:
     * https://webservices.amazon.com/paapi5/documentation/common-request-parameters.html#host-and-region
     */
    $config->setHost('webservices.amazon.com');
    $config->setRegion('us-east-1');

    $apiInstance = new DefaultApi(
        /*
         * If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
         * This is optional, `GuzzleHttp\Client` will be used as default.
         */
        new GuzzleHttp\Client(),
        $config
    );

    # Request initialization

    # Specify keywords
    $keyword = 'Harry Potter';

    /*
     * Specify the category in which search request is to be made
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/use-cases/organization-of-items-on-amazon/search-index.html
     */
    $searchIndex = "All";

    # Specify item count to be returned in search result
    $itemCount = 1;

    /*
     * Choose resources you want from SearchItemsResource enum
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/search-items.html#resources-parameter
     */
    $resources = [
        SearchItemsResource::ITEM_INFOTITLE,
        SearchItemsResource::OFFERSLISTINGSPRICE];

    # Forming the request
    $searchItemsRequest = new SearchItemsRequest();
    $searchItemsRequest->setSearchIndex($searchIndex);
    $searchItemsRequest->setKeywords($keyword);
    $searchItemsRequest->setItemCount($itemCount);
    $searchItemsRequest->setPartnerTag($partnerTag);
    $searchItemsRequest->setPartnerType(PartnerType::ASSOCIATES);
    $searchItemsRequest->setResources($resources);

    # Validating request
    $invalidPropertyList = $searchItemsRequest->listInvalidProperties();
    $length = count($invalidPropertyList);
    if ($length > 0) {
        echo "Error forming the request", PHP_EOL;
        foreach ($invalidPropertyList as $invalidProperty) {
            echo $invalidProperty, PHP_EOL;
        }
        return;
    }

    # Sending the request
    try {
        $responseWithHttpInfo = $apiInstance->searchItemsWithHttpInfo($searchItemsRequest);

        echo 'API called successfully', PHP_EOL;
        echo 'Complete Response dump: ';
        var_dump($responseWithHttpInfo);
        echo "HTTP Info: ";
        var_dump($responseWithHttpInfo[2]);

        # Parsing the response
        $response = $responseWithHttpInfo[0];
        if ($response->getSearchResult() !== null) {
            echo 'Printing first item information in SearchResult:', PHP_EOL;
            $item = $response->getSearchResult()->getItems()[0];
            if ($item !== null) {
                if ($item->getASIN() !== null) {
                    echo "ASIN: ", $item->getASIN(), PHP_EOL;
                }
                if ($item->getDetailPageURL() !== null) {
                    echo "DetailPageURL: ", $item->getDetailPageURL(), PHP_EOL;
                }
                if ($item->getItemInfo() !== null
                    and $item->getItemInfo()->getTitle() !== null
                    and $item->getItemInfo()->getTitle()->getDisplayValue() !== null) {
                    echo "Title: ", $item->getItemInfo()->getTitle()->getDisplayValue(), PHP_EOL;
                }
                if ($item->getOffers() !== null
                    and $item->getOffers() !== null
                    and $item->getOffers()->getListings() !== null
                    and $item->getOffers()->getListings()[0]->getPrice() !== null
                    and $item->getOffers()->getListings()[0]->getPrice()->getDisplayAmount() !== null) {
                    echo "Buying price: ", $item->getOffers()->getListings()[0]->getPrice()
                        ->getDisplayAmount(), PHP_EOL;
                }
            }
        }
        if ($response->getErrors() !== null) {
            echo PHP_EOL, 'Printing Errors:', PHP_EOL, 'Printing first error object from list of errors', PHP_EOL;
            echo 'Error code: ', $response->getErrors()[0]->getCode(), PHP_EOL;
            echo 'Error message: ', $response->getErrors()[0]->getMessage(), PHP_EOL;
        }
    } catch (ApiException $exception) {
        echo "Error calling PA-API 5.0!", PHP_EOL;
        echo "HTTP Status Code: ", $exception->getCode(), PHP_EOL;
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
        if ($exception->getResponseObject() instanceof ProductAdvertisingAPIClientException) {
            $errors = $exception->getResponseObject()->getErrors();
            foreach ($errors as $error) {
                echo "Error Type: ", $error->getCode(), PHP_EOL;
                echo "Error Message: ", $error->getMessage(), PHP_EOL;
            }
        } else {
            echo "Error response body: ", $exception->getResponseBody(), PHP_EOL;
        }
    } catch (Exception $exception) {
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
    }
}

function searchItemsAsync()
{
    $config = new Configuration();

    /*
     * Add your credentials
     */
    # Please add your access key here
    $config->setAccessKey('<YOUR ACCESS KEY>');
    # Please add your secret key here
    $config->setSecretKey('<YOUR SECRET KEY>');

    # Please add your partner tag (store/tracking id) here
    $partnerTag = '<YOUR PARTNER TAG>';

    /*
     * PAAPI host and region to which you want to send request
     * For more details refer:
     * https://webservices.amazon.com/paapi5/documentation/common-request-parameters.html#host-and-region
     */
    $config->setHost('webservices.amazon.com');
    $config->setRegion('us-east-1');

    $apiInstance = new DefaultApi(
        /*
         * If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
         * This is optional, `GuzzleHttp\Client` will be used as default.
         */
        new GuzzleHttp\Client(),
        $config
    );

    # Request initialization

    # Specify keywords
    $keyword = 'Harry Potter';

    /*
     * Specify the category in which search request is to be made
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/use-cases/organization-of-items-on-amazon/search-index.html
     */
    $searchIndex = "All";

    # Specify item count to be returned in search result
    $itemCount = 1;

    /*
     * Choose resources you want from SearchItemsResource enum
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/search-items.html#resources-parameter
     */
    $resources = [
        SearchItemsResource::ITEM_INFOTITLE,
        SearchItemsResource::OFFERSLISTINGSPRICE];

    # Forming the request
    $searchItemsRequest = new SearchItemsRequest();
    $searchItemsRequest->setSearchIndex($searchIndex);
    $searchItemsRequest->setKeywords($keyword);
    $searchItemsRequest->setItemCount($itemCount);
    $searchItemsRequest->setPartnerTag($partnerTag);
    $searchItemsRequest->setPartnerType(PartnerType::ASSOCIATES);
    $searchItemsRequest->setResources($resources);

    # Validating request
    $invalidPropertyList = $searchItemsRequest->listInvalidProperties();
    $length = count($invalidPropertyList);
    if ($length > 0) {
        echo "Error forming the request", PHP_EOL;
        foreach ($invalidPropertyList as $invalidProperty) {
            echo $invalidProperty, PHP_EOL;
        }
        return;
    }

    # Sending the request
    try {
        $promise = $apiInstance->searchItemsAsync($searchItemsRequest);
        $response = $promise->wait();
        $promise->then(
            function ($response) {
                return $response;
            },
            function (\Exception $exception) {
                echo "Error Message: ", $exception->getMessage(), PHP_EOL;
                throw $exception;
            }
        );

        echo 'API called successfully', PHP_EOL;
        echo 'Complete Response: ', $response, PHP_EOL;

        # Parsing the response
        if ($response->getSearchResult() !== null) {
            echo 'Printing first item information in SearchResult:', PHP_EOL;
            $item = $response->getSearchResult()->getItems()[0];
            if ($item !== null) {
                if ($item->getASIN() !== null) {
                    echo "ASIN: ", $item->getASIN(), PHP_EOL;
                }
                if ($item->getDetailPageURL() !== null) {
                    echo "DetailPageURL: ", $item->getDetailPageURL(), PHP_EOL;
                }
                if ($item->getItemInfo() !== null
                    and $item->getItemInfo()->getTitle() !== null
                    and $item->getItemInfo()->getTitle()->getDisplayValue() !== null) {
                    echo "Title: ", $item->getItemInfo()->getTitle()->getDisplayValue(), PHP_EOL;
                }
                if ($item->getOffers() !== null
                    and $item->getOffers() !== null
                    and $item->getOffers()->getListings() !== null
                    and $item->getOffers()->getListings()[0]->getPrice() !== null
                    and $item->getOffers()->getListings()[0]->getPrice()->getDisplayAmount() !== null) {
                    echo "Buying price: ", $item->getOffers()->getListings()[0]->getPrice()
                        ->getDisplayAmount(), PHP_EOL;
                }
            }
        }
        if ($response->getErrors() !== null) {
            echo PHP_EOL, 'Printing Errors:', PHP_EOL, 'Printing first error object from list of errors', PHP_EOL;
            echo 'Error code: ', $response->getErrors()[0]->getCode(), PHP_EOL;
            echo 'Error message: ', $response->getErrors()[0]->getMessage(), PHP_EOL;
        }
    } catch (ApiException $exception) {
        echo "Error calling PA-API 5.0!", PHP_EOL;
        echo "HTTP Status Code: ", $exception->getCode(), PHP_EOL;
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
        if ($exception->getResponseObject() instanceof ProductAdvertisingAPIClientException) {
            $errors = $exception->getResponseObject()->getErrors();
            foreach ($errors as $error) {
                echo "Error Type: ", $error->getCode(), PHP_EOL;
                echo "Error Message: ", $error->getMessage(), PHP_EOL;
            }
        } else {
            echo "Error response body: ", $exception->getResponseBody(), PHP_EOL;
        }
    } catch (Exception $exception) {
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
    }
}

function searchItemsAsyncWithHttpInfo()
{
    $config = new Configuration();

    /*
     * Add your credentials
     */
    # Please add your access key here
    $config->setAccessKey('<YOUR ACCESS KEY>');
    # Please add your secret key here
    $config->setSecretKey('<YOUR SECRET KEY>');

    # Please add your partner tag (store/tracking id) here
    $partnerTag = '<YOUR PARTNER TAG>';

    /*
     * PAAPI host and region to which you want to send request
     * For more details refer:
     * https://webservices.amazon.com/paapi5/documentation/common-request-parameters.html#host-and-region
     */
    $config->setHost('webservices.amazon.com');
    $config->setRegion('us-east-1');

    $apiInstance = new DefaultApi(
        /*
         * If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
         * This is optional, `GuzzleHttp\Client` will be used as default.
         */
        new GuzzleHttp\Client(),
        $config
    );

    # Request initialization

    # Specify keywords
    $keyword = 'Harry Potter';

    /*
     * Specify the category in which search request is to be made
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/use-cases/organization-of-items-on-amazon/search-index.html
     */
    $searchIndex = "All";

    # Specify item count to be returned in search result
    $itemCount = 1;

    /*
     * Choose resources you want from SearchItemsResource enum
     * For more details, refer:
     * https://webservices.amazon.com/paapi5/documentation/search-items.html#resources-parameter
     */
    $resources = [
        SearchItemsResource::ITEM_INFOTITLE,
        SearchItemsResource::OFFERSLISTINGSPRICE];

    # Forming the request
    $searchItemsRequest = new SearchItemsRequest();
    $searchItemsRequest->setSearchIndex($searchIndex);
    $searchItemsRequest->setKeywords($keyword);
    $searchItemsRequest->setItemCount($itemCount);
    $searchItemsRequest->setPartnerTag($partnerTag);
    $searchItemsRequest->setPartnerType(PartnerType::ASSOCIATES);
    $searchItemsRequest->setResources($resources);

    # Validating request
    $invalidPropertyList = $searchItemsRequest->listInvalidProperties();
    $length = count($invalidPropertyList);
    if ($length > 0) {
        echo "Error forming the request", PHP_EOL;
        foreach ($invalidPropertyList as $invalidProperty) {
            echo $invalidProperty, PHP_EOL;
        }
        return;
    }

    # Sending the request
    try {
        $promise = $apiInstance->searchItemsAsyncWithHttpInfo($searchItemsRequest);
        $responseWithHttpInfo = $promise->wait();
        $promise->then(
            function ($response) {
                return $response;
            },
            function (\Exception $exception) {
                echo "Error Message: ", $exception->getMessage(), PHP_EOL;
                throw $exception;
            }
        );

        echo 'API called successfully', PHP_EOL;
        echo 'Complete Response dump: ';
        var_dump($responseWithHttpInfo);
        echo "HTTP Info: ";
        var_dump($responseWithHttpInfo[2]);

        # Parsing the response
        $response = $responseWithHttpInfo[0];
        if ($response->getSearchResult() !== null) {
            echo 'Printing first item information in SearchResult:', PHP_EOL;
            $item = $response->getSearchResult()->getItems()[0];
            if ($item !== null) {
                if ($item->getASIN() !== null) {
                    echo "ASIN: ", $item->getASIN(), PHP_EOL;
                }
                if ($item->getDetailPageURL() !== null) {
                    echo "DetailPageURL: ", $item->getDetailPageURL(), PHP_EOL;
                }
                if ($item->getItemInfo() !== null
                    and $item->getItemInfo()->getTitle() !== null
                    and $item->getItemInfo()->getTitle()->getDisplayValue() !== null) {
                    echo "Title: ", $item->getItemInfo()->getTitle()->getDisplayValue(), PHP_EOL;
                }
                if ($item->getOffers() !== null
                    and $item->getOffers() !== null
                    and $item->getOffers()->getListings() !== null
                    and $item->getOffers()->getListings()[0]->getPrice() !== null
                    and $item->getOffers()->getListings()[0]->getPrice()->getDisplayAmount() !== null) {
                    echo "Buying price: ", $item->getOffers()->getListings()[0]->getPrice()
                        ->getDisplayAmount(), PHP_EOL;
                }
            }
        }
        if ($response->getErrors() !== null) {
            echo PHP_EOL, 'Printing Errors:', PHP_EOL, 'Printing first error object from list of errors', PHP_EOL;
            echo 'Error code: ', $response->getErrors()[0]->getCode(), PHP_EOL;
            echo 'Error message: ', $response->getErrors()[0]->getMessage(), PHP_EOL;
        }
    } catch (ApiException $exception) {
        echo "Error calling PA-API 5.0!", PHP_EOL;
        echo "HTTP Status Code: ", $exception->getCode(), PHP_EOL;
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
        if ($exception->getResponseObject() instanceof ProductAdvertisingAPIClientException) {
            $errors = $exception->getResponseObject()->getErrors();
            foreach ($errors as $error) {
                echo "Error Type: ", $error->getCode(), PHP_EOL;
                echo "Error Message: ", $error->getMessage(), PHP_EOL;
            }
        } else {
            echo "Error response body: ", $exception->getResponseBody(), PHP_EOL;
        }
    } catch (Exception $exception) {
        echo "Error Message: ", $exception->getMessage(), PHP_EOL;
    }
}


searchItems();
#searchItemsWithHttpInfo();
#searchItemsAsync();
#searchItemsAsyncWithHttpInfo();
